package com.ruoyi.project.business.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.project.business.domain.dto.TtTrainDto;
import com.ruoyi.project.business.domain.dto.TtTrainSearchDto;
import com.ruoyi.project.business.domain.train.TtTrain;
import com.ruoyi.project.business.domain.vo.train.*;

import java.util.List;

/**
 * 培训考核Service接口
 *
 * @author ruoyi
 * @date 2024-06-18
 */
public interface ITtTrainService extends IService<TtTrain> {
    /**
     * 查询培训考核
     *
     * @param id 培训考核主键
     * @return 培训考核
     */
    TtTrainVo selectTtTrainById(Long id);

    /**
     * 查询培训考核列表
     *
     * @param ttTrainSearchDto 培训考核
     * @return 培训考核集合
     */
    List<TtTrainVo> selectTtTrainList(TtTrainSearchDto ttTrainSearchDto);

    /**
     * 新增培训考核
     *
     * @param ttTrainDto 培训考核
     * @return 结果
     */
    int insertTtTrain(TtTrainDto ttTrainDto);

    /**
     * 修改培训考核
     *
     * @param ttTrainDto 培训考核
     * @return 结果
     */
    int updateTtTrain(TtTrainDto ttTrainDto);

    /**
     * 批量删除
     *
     * @param ids 需要删除的培训考核主键集合
     * @return 结果
     */
    int deleteTtTrainByIds(Long[] ids);

    /**
     * 删除
     *
     * @param id 培训考核主键
     * @return 结果
     */
    int deleteTtTrainById(Long id);

    /**
     * 查询当前用户参与的培训列表
     */
    List<TrainParticipantRes> selectParticipantTrainListCur(TrainParticipantReq req);

    TtTestPaperVo selectTestPaperDetail(TtTrainDto ttTrainDto);

    TtTestPaperVo selectTestResult(TtTrainDto ttTrainDto);

    List<TtTrainTargetVo> selectTrainResult(TtTrainDto ttTrainDto);

    void updateTrainStatus();

    int updateTtTrainStatusByIds(Long[] ids);
}
